@@ -1,5 +1,3 @@
-/* $Id: open.c,v 1.43 2006/04/10 08:41:46 bdejean Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -150,7 +148,7 @@ glibtop_open_l (glibtop *server, const char *program_name,
 		if (nbytes != size)
 			glibtop_error_r (server,
 					 "Requested %u bytes but got %u.",
-					 size, nbytes);
+					 (unsigned)size, (unsigned)nbytes);
 
 		glibtop_read_l (server, nbytes, buffer);
 
