@@ -1,5 +1,3 @@
-/* $Id: utils.c,v 1.2 2003/10/19 16:54:39 carlos Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,6 +19,7 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <nlist.h>
 
 #include <procinfo.h>
@@ -29,7 +28,6 @@
 
 #include <glibtop.h>
 #include <glibtop/error.h>
-#include <glibtop/xmalloc.h>
 #include "glibtop_suid.h"
 #include "utils.h"
 
